# Amara 3 Core

Core of Amara3 project, which contains a variety of data processing tools, is a module for handling Internationalized Resource Identifiers (IRIs)

Uche Ogbuji
uche@ogbuji.net

## Install

Requires Python 3.5+. Just run:

```
pip install amara3.iri
```

